@@ -1,6 +1,8 @@
+
+
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2007 Andrey Korotaev <unC0Rr@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2007-2010 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,16 +21,29 @@
 #ifndef SDLS_H
 #define SDLS_H
 
+
 #include <QStringList>
+#include "SDL_mixer.h"
+
 
 class SDLInteraction : public QObject
 {
-	Q_OBJECT
+    Q_OBJECT
 
-	public:
-	SDLInteraction();
-	~SDLInteraction();
-	QStringList getResolutions() const;
+private:
+    Mix_Music *music;
+    int musicInitialized;
+
+public:
+    SDLInteraction();
+    ~SDLInteraction();
+    QStringList getResolutions() const;
+    void addGameControllerKeys() const;
+    void StartMusic();
+    void StopMusic();
+    void SDLMusicInit();
 };
 
+
 #endif
+
