@@ -1,6 +1,6 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2006 Andrey Korotaev <unC0Rr@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2006-2010 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,29 +19,32 @@
 #include <QPaintEvent>
 #include <QPainter>
 #include "SquareLabel.h"
+#include "hwform.h"
 
 SquareLabel::SquareLabel(QWidget * parent) :
-	QWidget(parent)
+    QWidget(parent)
 {
-
+    if(frontendEffects) setAttribute(Qt::WA_PaintOnScreen, true);
 }
 
 void SquareLabel::paintEvent(QPaintEvent * event)
 {
-	QPainter painter(this);
-	int pixsize;
-	if (width() > height()) {
-		pixsize = height();
-		painter.translate((width() - pixsize) / 2, 0);
-	} else {
-		pixsize = width();
-		painter.translate(0, (height() - pixsize) / 2);
-	}
-	painter.drawPixmap(0, 0, pixsize, pixsize, pixmap.scaled(pixsize, pixsize, Qt::KeepAspectRatio));
+    Q_UNUSED(event);
+
+    QPainter painter(this);
+    int pixsize;
+    if (width() > height()) {
+        pixsize = height();
+        painter.translate((width() - pixsize) / 2, 0);
+    } else {
+        pixsize = width();
+        painter.translate(0, (height() - pixsize) / 2);
+    }
+    painter.drawPixmap(0, 0, pixsize, pixsize, pixmap.scaled(pixsize, pixsize, Qt::KeepAspectRatio));
 }
 
 void SquareLabel::setPixmap(const QPixmap & pixmap)
 {
-	this->pixmap = pixmap;
-	repaint();
+    this->pixmap = pixmap;
+    repaint();
 }
