@@ -1,6 +1,6 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2005, 2006, 2007 Andrey Korotaev <unC0Rr@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2005-2010 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,14 +21,19 @@
 
 #include <QString>
 
-#define BINDS_NUMBER 32
+#ifdef _WIN32
+#define BINDS_NUMBER 43
+#else
+#define BINDS_NUMBER 44
+#endif
 
 struct BindAction
 {
-	QString action;
-	QString strbind;
-	const char * name;
-	bool chwidget;
+    QString action;
+    QString strbind;
+    const char * name;
+    const char * category;
+    const char * description;
 };
 
 extern const BindAction cbinds[BINDS_NUMBER];
