@@ -1,6 +1,6 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2006-2008 Ulyanov Igor <iulyanov@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,37 +20,39 @@
 
 #include "frameTeam.h"
 
-CHedgehogerWidget::CHedgehogerWidget(const QImage& im, QWidget * parent) :
-    ItemNum(im, parent)
+CHedgehogerWidget::CHedgehogerWidget(const QImage& im, const QImage& img, QWidget * parent) :
+    ItemNum(im, img, parent, 1)
 {
-  if(parent) {
-    pOurFrameTeams=dynamic_cast<FrameTeams*>(parent->parentWidget());
+  // TODO: maxHedgehogsPerGame doesn't reset properly and won't match map limits for now
+  /*if(parent) {
+    pOurFrameTeams = dynamic_cast<FrameTeams*>(parent->parentWidget());
   }
-  if(pOurFrameTeams->overallHedgehogs+4>pOurFrameTeams->maxHedgehogsPerGame) {
-    numItems=pOurFrameTeams->maxHedgehogsPerGame-pOurFrameTeams->overallHedgehogs;
-  } else numItems=4;
-  pOurFrameTeams->overallHedgehogs+=numItems;
+  if(pOurFrameTeams->overallHedgehogs + 4 > pOurFrameTeams->maxHedgehogsPerGame) {
+    numItems = pOurFrameTeams->maxHedgehogsPerGame - pOurFrameTeams->overallHedgehogs;
+  } else numItems = 4;
+  pOurFrameTeams->overallHedgehogs += numItems;*/
 }
 
-void CHedgehogerWidget::incItems() 
+void CHedgehogerWidget::incItems()
 {
-  if (pOurFrameTeams->overallHedgehogs<18) {
+  //if (pOurFrameTeams->overallHedgehogs < pOurFrameTeams->maxHedgehogsPerGame) {
     numItems++;
-    pOurFrameTeams->overallHedgehogs++;
+    //pOurFrameTeams->overallHedgehogs++;
     emit hedgehogsNumChanged();
-  }
+  //}
 }
 
 void CHedgehogerWidget::decItems()
 {
   numItems--;
-  pOurFrameTeams->overallHedgehogs--;
+  //pOurFrameTeams->overallHedgehogs--;
   emit hedgehogsNumChanged();
 }
 
 CHedgehogerWidget::~CHedgehogerWidget()
 {
-  pOurFrameTeams->overallHedgehogs-=numItems;
+  // TODO: not called?
+  //pOurFrameTeams->overallHedgehogs-=numItems;
 }
 
 void CHedgehogerWidget::setNonInteractive()
@@ -60,9 +62,10 @@ void CHedgehogerWidget::setNonInteractive()
 
 void CHedgehogerWidget::setHHNum(unsigned int num)
 {
-  unsigned int diff=numItems-num;
-  numItems=num;
-  pOurFrameTeams->overallHedgehogs+=diff;
+  /*unsigned int diff = num - numItems;
+  numItems += diff;
+  pOurFrameTeams->overallHedgehogs += diff;*/
+  numItems = num;
   repaint();
 }
 
