@@ -1,5 +1,5 @@
 /*
- * Hedgewars, a worms-like game
+ * Hedgewars, a free turn based strategy game
  * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@ class CHedgehogerWidget : public ItemNum
   Q_OBJECT
 
  public:
-  CHedgehogerWidget(const QImage& im, QWidget * parent);
+  CHedgehogerWidget(const QImage& im, const QImage& img, QWidget * parent);
   virtual ~CHedgehogerWidget();
   unsigned char getHedgehogsNum() const;
   void setHHNum (unsigned int num);
