@@ -21,7 +21,8 @@
 HWNetRegisterServer::HWNetRegisterServer(QObject *parent, const QString & descr, quint16 port) :
   QObject(parent)
 {
-
+    Q_UNUSED(descr);
+    Q_UNUSED(port);
 }
 
 void HWNetRegisterServer::unregister()
