@@ -1,5 +1,5 @@
 /*
- * Hedgewars, a worms-like game
+ * Hedgewars, a free turn based strategy game
  * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,7 @@ class TeamSelWidget : public QGroupBox
   bool isPlaying(HWTeam team) const;
   QList<HWTeam> getPlayingTeams() const;
   QList<HWTeam> getDontPlayingTeams() const;
-  void setNonInteractive();
+  void setInteractivity(bool interactive);
 
  public slots:
   void addTeam(HWTeam team);
@@ -56,7 +56,6 @@ class TeamSelWidget : public QGroupBox
 
  signals:
   void setEnabledGameStart(bool);
-  void SetupClicked();
   void teamWillPlay(HWTeam team);
   void teamNotPlaying(const HWTeam& team);
   void hhogsNumChanged(const HWTeam&);
