@@ -1,6 +1,6 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2006, 2007 Ulyanov Igor <iulyanov@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2006-2008 Ulyanov Igor <iulyanov@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ class WeaponItem : public ItemNum
   Q_OBJECT
 
  public:
-  WeaponItem(const QImage& im, QWidget * parent);
+  WeaponItem(const QImage& im, const QImage& img, QWidget * parent);
   virtual ~WeaponItem();
 
  signals:
