@@ -7,6 +7,10 @@
         <source>new</source>
         <translation type="unfinished">Нов отбор</translation>
     </message>
+    <message>
+        <source>copy of</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FreqSpinBox</name>
@@ -41,7 +45,7 @@
         <translation>Невалидна оръжейна схема</translation>
     </message>
     <message>
-        <source>When this option is enabled selecting a game scheme will auto-select a weapon (and viceversa)</source>
+        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -84,7 +88,7 @@
     </message>
     <message>
         <source>new</source>
-        <translation>Нов отбор</translation>
+        <translation type="obsolete">Нов отбор</translation>
     </message>
     <message>
         <source>Please select record from the list above</source>
@@ -182,6 +186,14 @@
         <source>Large floating islands</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Seed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -293,6 +305,37 @@ or pick another nickname in game config:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>PageDrawMap</name>
+    <message>
+        <source>Undo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load</source>
+        <translation type="unfinished">Зареждане</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load drawn map</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save drawn map</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PageEditTeam</name>
     <message>
@@ -675,22 +718,34 @@ or pick another nickname in game config:</source>
         <source>Delete team</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>New weapon scheme</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Edit weapon scheme</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Delete weapon scheme</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>New scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New weapon set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit weapon set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete weapon set</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PagePlayDemo</name>
@@ -941,6 +996,18 @@ Do you still want to join the room?</source>
         <source>Each hedgehog has its own ammo. It does not share with the team.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>You will not have to worry about wind anymore.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wind will affect almost everything.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -952,6 +1019,14 @@ Do you still want to join the room?</source>
         <source>Delete</source>
         <translation>Изтриване</translation>
     </message>
+    <message>
+        <source>New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSinglePlayer</name>
@@ -1124,6 +1199,10 @@ Do you still want to join the room?</source>
         <source>Default</source>
         <translation type="obsolete">По подразбиране</translation>
     </message>
+    <message>
+        <source>hand drawn map...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -1165,7 +1244,7 @@ Do you still want to join the room?</source>
     </message>
     <message>
         <source>Weapons</source>
-        <translation>Оръжия</translation>
+        <translation type="obsolete">Оръжия</translation>
     </message>
     <message>
         <source>Team Settings</source>
@@ -1175,6 +1254,10 @@ Do you still want to join the room?</source>
         <source>Misc</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Schemes and Weapons</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -1343,7 +1426,11 @@ Do you still want to join the room?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Bind schemes and weapons</source>
+        <source>% Rope Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gameplay</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1389,7 +1476,7 @@ Please check your installation</source>
     </message>
     <message>
         <source>Can not delete default weapon set</source>
-        <translation>Не могат да се изтрият оръжията по подразбиране</translation>
+        <translation type="obsolete">Не могат да се изтрият оръжията по подразбиране</translation>
     </message>
     <message>
         <source>Really delete this weapon set?</source>
@@ -1411,6 +1498,30 @@ Please check your installation</source>
         <source>File association failed.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Teams</source>
+        <translation type="unfinished">Отбори</translation>
+    </message>
+    <message>
+        <source>Really delete this team?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Schemes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Can not delete default scheme &apos;%1&apos;!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Really delete this game scheme?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Can not delete default weapon set &apos;%1&apos;!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -1505,6 +1616,10 @@ Please check your installation</source>
         <source>Associate file extensions</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>more</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -1555,6 +1670,14 @@ Please check your installation</source>
         <source>Delays</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>new</source>
+        <translation type="unfinished">Нов отбор</translation>
+    </message>
+    <message>
+        <source>copy of</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -1657,6 +1780,14 @@ Please check your installation</source>
         <source>Per Hedgehog Ammo</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Disable Wind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>More Wind</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
