@@ -7,6 +7,10 @@
         <source>new</source>
         <translation>Nuevo</translation>
     </message>
+    <message>
+        <source>copy of</source>
+        <translation>Copia de</translation>
+    </message>
 </context>
 <context>
     <name>FreqSpinBox</name>
@@ -42,7 +46,11 @@
     </message>
     <message>
         <source>When this option is enabled selecting a game scheme will auto-select a weapon (and viceversa)</source>
-        <translation>Cuando esta opción esté activada escoger un modo de juego escogerá el set de armas correspondiente (y viceversa)</translation>
+        <translation type="obsolete">Cuando esta opción esté activada escoger un modo de juego escogerá el set de armas correspondiente (y viceversa)</translation>
+    </message>
+    <message>
+        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
+        <translation>Cuando esta opción esté activada escoger un modo de juego escogerá el set de armas correspondiente</translation>
     </message>
 </context>
 <context>
@@ -84,7 +92,7 @@
     </message>
     <message>
         <source>new</source>
-        <translation>Nuevo</translation>
+        <translation type="obsolete">Nuevo</translation>
     </message>
     <message>
         <source>Please select record from the list above</source>
@@ -186,6 +194,14 @@
         <source>Large floating islands</source>
         <translation>Islas grandes</translation>
     </message>
+    <message>
+        <source>Seed</source>
+        <translation>Semilla</translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished">Establecer</translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -318,6 +334,37 @@ o elige otro nick en las preferencias del juego:</translation>
         <translation>Conectando...</translation>
     </message>
 </context>
+<context>
+    <name>PageDrawMap</name>
+    <message>
+        <source>Undo</source>
+        <translation>Deshacer</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Limpiar</translation>
+    </message>
+    <message>
+        <source>Load</source>
+        <translation>Cargar</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Guardar</translation>
+    </message>
+    <message>
+        <source>Load drawn map</source>
+        <translation>Cargar mapa</translation>
+    </message>
+    <message>
+        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
+        <translation>Mapas dibujados a mano (*.hwmap);;Todos los ficheros (*.*)</translation>
+    </message>
+    <message>
+        <source>Save drawn map</source>
+        <translation>Guardar mapa</translation>
+    </message>
+</context>
 <context>
     <name>PageEditTeam</name>
     <message>
@@ -730,20 +777,44 @@ o elige otro nick en las preferencias del juego:</translation>
     </message>
     <message>
         <source>New weapon scheme</source>
-        <translation>Nuevo set de armas</translation>
+        <translation type="obsolete">Nuevo set de armas</translation>
     </message>
     <message>
         <source>Edit weapon scheme</source>
-        <translation>Editar set de armas</translation>
+        <translation type="obsolete">Editar set de armas</translation>
     </message>
     <message>
         <source>Delete weapon scheme</source>
-        <translation>Borrar set de armas</translation>
+        <translation type="obsolete">Borrar set de armas</translation>
     </message>
     <message>
         <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
         <translation>No es posible editar equipos desde la pantalla de elección de equipo. Vuelve al menú principal para añadir, editar o borrar equipos.</translation>
     </message>
+    <message>
+        <source>New scheme</source>
+        <translation>Nuevo modo de juego</translation>
+    </message>
+    <message>
+        <source>Edit scheme</source>
+        <translation>Editar modo de juego</translation>
+    </message>
+    <message>
+        <source>Delete scheme</source>
+        <translation>Eliminar modo de juego</translation>
+    </message>
+    <message>
+        <source>New weapon set</source>
+        <translation>Nuevo set de armas</translation>
+    </message>
+    <message>
+        <source>Edit weapon set</source>
+        <translation>Editar set de armas</translation>
+    </message>
+    <message>
+        <source>Delete weapon set</source>
+        <translation>Eliminar set de armas</translation>
+    </message>
 </context>
 <context>
     <name>PagePlayDemo</name>
@@ -1001,6 +1072,18 @@ Do you still want to join the room?</source>
         <source>All (living) hedgehogs are fully restored at the end of turn</source>
         <translation>La salud de todos los erizos en pie es restaurada al final de cada turno</translation>
     </message>
+    <message>
+        <source>You will not have to worry about wind anymore.</source>
+        <translation>No tendrás que volver a preocuparte del viento.</translation>
+    </message>
+    <message>
+        <source>Wind will affect almost everything.</source>
+        <translation>El viento afectará a (casi) todo.</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation>Copiar</translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -1012,6 +1095,14 @@ Do you still want to join the room?</source>
         <source>Delete</source>
         <translation>Borrar</translation>
     </message>
+    <message>
+        <source>New</source>
+        <translation>Nuevo</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation>Copiar</translation>
+    </message>
 </context>
 <context>
     <name>PageSinglePlayer</name>
@@ -1216,6 +1307,14 @@ Do you still want to join the room?</source>
         <source>Crazy</source>
         <translation type="obsolete">Lunático</translation>
     </message>
+    <message>
+        <source>Normal</source>
+        <translation type="obsolete">Normal</translation>
+    </message>
+    <message>
+        <source>hand drawn map...</source>
+        <translation>Mapa dibujado a mano...</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -1241,7 +1340,7 @@ Do you still want to join the room?</source>
     </message>
     <message>
         <source>Weapons</source>
-        <translation>Sets de armas</translation>
+        <translation type="obsolete">Sets de armas</translation>
     </message>
     <message>
         <source>Net game</source>
@@ -1267,6 +1366,10 @@ Do you still want to join the room?</source>
         <source>Misc</source>
         <translation>Otras opciones</translation>
     </message>
+    <message>
+        <source>Schemes and Weapons</source>
+        <translation>Modos de juego y sets de armas</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -1445,7 +1548,15 @@ así como carecer de algunas funcionalidades o simplemente funcionar mal.
     </message>
     <message>
         <source>Bind schemes and weapons</source>
-        <translation>Enlazar modos y sets</translation>
+        <translation type="obsolete">Enlazar modos y sets</translation>
+    </message>
+    <message>
+        <source>% Rope Length</source>
+        <translation>% longitud de las cuerdas</translation>
+    </message>
+    <message>
+        <source>Gameplay</source>
+        <translation>Tipo de juego</translation>
     </message>
 </context>
 <context>
@@ -1494,7 +1605,7 @@ Por favor, compruebe que el juego está debidamente instalado</translation>
     </message>
     <message>
         <source>Can not delete default weapon set</source>
-        <translation>No se puede borrar el set de armas predefinido</translation>
+        <translation type="obsolete">No se puede borrar el set de armas predefinido</translation>
     </message>
     <message>
         <source>Really delete this weapon set?</source>
@@ -1512,6 +1623,30 @@ Por favor, compruebe que el juego está debidamente instalado</translation>
         <source>File association failed.</source>
         <translation>No se pudieron asociar los tipos de fichero.</translation>
     </message>
+    <message>
+        <source>Teams</source>
+        <translation>Equipos</translation>
+    </message>
+    <message>
+        <source>Really delete this team?</source>
+        <translation>¿De verdad quieres eliminar este equipo?</translation>
+    </message>
+    <message>
+        <source>Schemes</source>
+        <translation>Modos de juego</translation>
+    </message>
+    <message>
+        <source>Can not delete default scheme &apos;%1&apos;!</source>
+        <translation>¡No se puede eliminar el modo de juego predefinido &apos;%1&apos;!</translation>
+    </message>
+    <message>
+        <source>Really delete this game scheme?</source>
+        <translation>¿De verdad quieres eliminar este modo de juego?</translation>
+    </message>
+    <message>
+        <source>Can not delete default weapon set &apos;%1&apos;!</source>
+        <translation>¡No se puede eliminar el set de armas predefinido &apos;%1&apos;!</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -1606,6 +1741,14 @@ Por favor, compruebe que el juego está debidamente instalado</translation>
         <source>Associate file extensions</source>
         <translation>Asociar tipos de archivo</translation>
     </message>
+    <message>
+        <source>Set</source>
+        <translation type="obsolete">Establecer</translation>
+    </message>
+    <message>
+        <source>more</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -1646,7 +1789,7 @@ Por favor, compruebe que el juego está debidamente instalado</translation>
     </message>
     <message>
         <source>Probabilities</source>
-        <translation>Probabilidad</translation>
+        <translation>Probabilidades</translation>
     </message>
     <message>
         <source>Ammo in boxes</source>
@@ -1656,6 +1799,14 @@ Por favor, compruebe que el juego está debidamente instalado</translation>
         <source>Delays</source>
         <translation>Retraso</translation>
     </message>
+    <message>
+        <source>new</source>
+        <translation>Nuevo</translation>
+    </message>
+    <message>
+        <source>copy of</source>
+        <translation>Copia de</translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -1762,6 +1913,14 @@ Por favor, compruebe que el juego está debidamente instalado</translation>
         <source>Reset Health</source>
         <translation>Restaurar salud</translation>
     </message>
+    <message>
+        <source>Disable Wind</source>
+        <translation>Deshabilitar viento</translation>
+    </message>
+    <message>
+        <source>More Wind</source>
+        <translation>Más viento</translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
